@@ -364,11 +364,12 @@ handle_close (XdpImplRequest *object,
                                                handle->invocation,
                                                2,
                                                g_variant_builder_end (&opt_builder));
-  file_dialog_handle_close (handle);
 
   if (handle->request->exported)
     request_unexport (handle->request);
 
+  file_dialog_handle_close (handle);
+
   xdp_impl_request_complete_close (object, invocation);
 
   return TRUE;
@@ -556,7 +557,7 @@ handle_open (XdpImplFileChooser *object,
       g_autoptr (GtkFileFilter) filter = NULL;
       const char *current_filter_name;
 
-      filter = gtk_file_filter_new_from_gvariant (current_filter);
+      filter = g_object_ref_sink (gtk_file_filter_new_from_gvariant (current_filter));
       current_filter_name = gtk_file_filter_get_name (filter);
 
       if (!filters)
@@ -595,7 +596,12 @@ handle_open (XdpImplFileChooser *object,
     }
   g_slist_free_full (filters, g_object_unref);
 
-  if (strcmp (method_name, "SaveFile") == 0)
+  if (strcmp (method_name, "OpenFile") == 0)
+    {
+      if (g_variant_lookup (arg_options, "current_folder", "^&ay", &path))
+        gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), path);
+    }
+  else if (strcmp (method_name, "SaveFile") == 0)
     {
       if (g_variant_lookup (arg_options, "current_name", "&s", &current_name))
         gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), current_name);
